@@ -42,7 +42,7 @@ class DcrawBinaryPriv;
 
 class LIBKDCRAW_EXPORT DcrawBinary : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
